@@ -90,14 +90,14 @@ int oidc_cache_shm_post_config(server_rec *s) {
 
 	if (cfg->cache_cfg != NULL)
 		return APR_SUCCESS;
-	oidc_cache_cfg_shm_t *context = oidc_cache_shm_cfg_create(s->process->pool);
+	oidc_cache_cfg_shm_t *context = oidc_cache_shm_cfg_create(s->process->pconf);
 	cfg->cache_cfg = context;
 
 	/* create the shared memory segment */
 	apr_status_t rv = apr_shm_create(&context->shm,
 			(apr_size_t) cfg->cache_shm_entry_size_max
 			* cfg->cache_shm_size_max,
-			NULL, s->process->pool);
+			NULL, s->process->pconf);
 	if (rv != APR_SUCCESS) {
 		oidc_serror(s, "apr_shm_create failed to create shared memory segment");
 		return HTTP_INTERNAL_SERVER_ERROR;
@@ -238,8 +238,8 @@ static apr_byte_t oidc_cache_shm_set(request_rec *r, const char *section,
 					> (cfg->cache_shm_entry_size_max
 							- sizeof(oidc_cache_shm_entry_t)))) {
 		oidc_error(r,
-				"could not store value since value size is too large (%llu > %lu); consider increasing " OIDCCacheShmEntrySizeMax "",
-				(unsigned long long )strlen(value),
+				"could not store value since value size is too large (%lu > %lu); consider increasing " OIDCCacheShmEntrySizeMax "",
+				(unsigned long )strlen(value),
 				(unsigned long )(cfg->cache_shm_entry_size_max
 						- sizeof(oidc_cache_shm_entry_t)));
 		return FALSE;
