@@ -66,7 +66,7 @@ static apr_byte_t oidc_session_encode(request_rec *r, oidc_cfg *c, oidc_session_
 		return (*s_value != NULL);
 	}
 
-	if (oidc_util_jwt_create(r, c->crypto_passphrase, z->state, s_value, TRUE) == FALSE)
+	if (oidc_util_jwt_create(r, c->crypto_passphrase, z->state, s_value, FALSE) == FALSE)
 		return FALSE;
 
 	return TRUE;
@@ -79,7 +79,7 @@ static apr_byte_t oidc_session_decode(request_rec *r, oidc_cfg *c, oidc_session_
 		return oidc_util_decode_json_object(r, s_json, &z->state);
 	}
 
-	if (oidc_util_jwt_verify(r, c->crypto_passphrase, s_json, &z->state, TRUE) == FALSE) {
+	if (oidc_util_jwt_verify(r, c->crypto_passphrase, s_json, &z->state, FALSE) == FALSE) {
 		oidc_error(r, "could not verify secure JWT: cache value possibly corrupted");
 		return FALSE;
 	}
